@@ -97,6 +97,25 @@ AFL_TEAM_IDENTITY_MAP = {
     "Narrm": MELBOURNE,
     "Waalitj Marawar": WESTCOAST,
     "Euro-Yroke": STKILDA,
+    # ESPN
+    "8": GWS,
+    "15": ADELAIDE,
+    "3": WESTCOAST,
+    "7": PORT_ADELAIDE,
+    "16": ESSENDON,
+    "4": SWANS,
+    "12": RICHMOND,
+    "14": GEELONG,
+    "17": COLLINGWOOD,
+    "13": HAWTHORN,
+    "10": GOLDCOAST,
+    "1": FREMANTLE,
+    "5": KANGAROOS,
+    "6": BULLDOGS,
+    "11": BRISBANE_LIONS,
+    "9": CARLTON,
+    "2": MELBOURNE,
+    "18": STKILDA,
 }
 BRUNSWICK_ST = "brunswick_st"
 VICTORIA_PARK = "victoria_park"
@@ -155,6 +174,34 @@ GIANTS_STADIUM = "Giants Stadium"
 TIPOS_ARENA = "Ondrej Nepela Arena"
 BAROSSA_PARK = "Barossa Park"
 HANDS_OVAL = "Hands Oval, Bunbury"
+HBF_ARENA = "45"
+FANKHAUSER_RESERVE = "57"
+CENTRAL_RESERVE = "56"
+CASEY_FIELDS = "34"
+ALBERTON_OVAL = "55"
+TED_SUMMERTON_RECREATIONAL_RESERVE = "27"
+NORM_MINNS_OVAL = "39"
+KINGSTON_TWINS_OVAL = "51"
+MORETON_BAY_CENTRAL_SPORTS_COMPLEX = "41"
+LEEDERVILLE_OVAL = "53"
+STRATHALBYN = "52"
+RIVERWAY_STADIUM = "54"
+MORWELL_RECREATION_RESERVE = "63"
+GREAT_BARRIER_REEF_ARENA = "37"
+DEAKIN_RESERVE = "47"
+DAVID_GRAYS_ARENA = "24"
+MEMORIAL_OVAL = "61"
+AVALON_AIRPORT_OVAL = "60"
+OAKES_OVAL = "62"
+FLINDERS_UNIVERSITY_STADIUM = "28"
+MINERAL_RESOURCES_PARK = "67"
+BENNETT_OVAL = "68"
+ROBERTSON_OVAL = "48"
+RSEA_PARK = "66"
+RICHMOND_OVAL = "20"
+DEVONPORT_OVAL = "71"
+BRIGHTON_HOMES_ARENA = "74"
+FREMANTLE_OVAL = "70"
 AFL_VENUE_IDENTITY_MAP = {
     "brunswick_st": BRUNSWICK_ST,
     "victoria_park": VICTORIA_PARK,
@@ -272,6 +319,51 @@ AFL_VENUE_IDENTITY_MAP = {
     "Hands Oval": HANDS_OVAL,
     "University of Tasmania Stadium, Launceston": YORK_PARK,
     "Ninja Stadium, Hobart": BELLERIVE_OVAL,
+    # ESPN
+    "6": ADELAIDE_OVAL,
+    "10": STADIUM_AUSTRALIA,
+    "7": SCG,
+    "1": MCG,
+    "2": SUBIACO,
+    "3": DOCKLANDS,
+    "5": GABBA,
+    "4": MANUKA_OVAL,
+    "9": YORK_PARK,
+    "45": HBF_ARENA,
+    "57": FANKHAUSER_RESERVE,
+    "56": CENTRAL_RESERVE,
+    "34": CASEY_FIELDS,
+    "55": ALBERTON_OVAL,
+    "27": TED_SUMMERTON_RECREATIONAL_RESERVE,
+    "39": NORM_MINNS_OVAL,
+    "51": KINGSTON_TWINS_OVAL,
+    "18": BLACKTOWN,
+    "19": PRINCES_PARK,
+    "41": MORETON_BAY_CENTRAL_SPORTS_COMPLEX,
+    "17": EUREKA,
+    "53": LEEDERVILLE_OVAL,
+    "52": STRATHALBYN,
+    "54": RIVERWAY_STADIUM,
+    "63": MORWELL_RECREATION_RESERVE,
+    "37": GREAT_BARRIER_REEF_ARENA,
+    "47": DEAKIN_RESERVE,
+    "24": DAVID_GRAYS_ARENA,
+    "61": MEMORIAL_OVAL,
+    "60": AVALON_AIRPORT_OVAL,
+    "62": OAKES_OVAL,
+    "13": KARDINIA_PARK,
+    "28": FLINDERS_UNIVERSITY_STADIUM,
+    "67": MINERAL_RESOURCES_PARK,
+    "68": BENNETT_OVAL,
+    "8": CARRARA,
+    "48": ROBERTSON_OVAL,
+    "66": RSEA_PARK,
+    "58": PERTH,
+    "36": ARDEN_ST,
+    "20": RICHMOND_OVAL,
+    "71": DEVONPORT_OVAL,
+    "74": BRIGHTON_HOMES_ARENA,
+    "70": FREMANTLE_OVAL,
 }
 
 
