@@ -6,8 +6,12 @@ import logging
 from typing import Any
 
 import requests
+from pydantic import BaseModel
 
+from ..field_type import TYPE_KEY, FieldType
 from ..game_model import VERSION, GameModel
+from ..league import League
+from ..player_model import PlayerModel
 from ..team_model import TeamModel
 from ..umpire_model import UmpireModel
 from ..venue_model import VenueModel
@@ -80,6 +84,30 @@ def _team_models(
     ]
 
 
+def _remove_lookaheads(obj: PlayerModel) -> PlayerModel:
+    """Set all fields marked as LOOKAHEAD to None, recursively."""
+    if isinstance(obj, BaseModel):
+        for name, f in obj.model_fields.items():
+            extra = getattr(f, "json_schema_extra", None) or {}
+            if extra.get(TYPE_KEY) == FieldType.LOOKAHEAD:
+                # validate_assignment=False means this won't revalidate
+                setattr(obj, name, None)
+            else:
+                # Recurse into nested values
+                val = getattr(obj, name, None)
+                _remove_lookaheads(val)  # type: ignore
+
+    elif isinstance(obj, list):
+        for item in obj:  # type: ignore
+            _remove_lookaheads(item)
+
+    elif isinstance(obj, dict):
+        for v in obj.values():  # type: ignore
+            _remove_lookaheads(v)
+
+    return obj
+
+
 def create_combined_game_model(
     game_models: list[GameModel],
     venue_identity_map: dict[str, str],
@@ -93,6 +121,7 @@ def create_combined_game_model(
     team_ffill: dict[str, dict[str, Any]],
     coach_ffill: dict[str, dict[str, Any]],
     umpire_ffill: dict[str, dict[str, Any]],
+    team_players_ffill: dict[str, list[PlayerModel]],
 ) -> GameModel:
     """Create a game model by combining many game models."""
     umpires: dict[str, list[UmpireModel]] = {}
@@ -160,6 +189,19 @@ def create_combined_game_model(
     if game_number is None and last_game_number is not None:
         game_number = last_game_number + 1
 
+    league = game_models[0].league
+
+    # Forward fill for team player models
+    if league == str(League.NFL) or league == str(League.WNBA):
+        for team_model in full_team_models:
+            if team_model.players:
+                team_players_ffill[team_model.identifier] = team_model.players
+                continue
+            team_model.players = [
+                _remove_lookaheads(x)
+                for x in team_players_ffill.get(team_model.identifier, [])
+            ]
+
     return GameModel.model_construct(
         dt=dt,
         week=week,
@@ -168,7 +210,7 @@ def create_combined_game_model(
         teams=full_team_models,
         end_dt=end_dt,
         attendance=attendance,
-        league=str(game_models[0].league),
+        league=league,
         year=year,
         season_type=season_type,
         postponed=postponed,
