@@ -30,6 +30,18 @@ FULHAM = "370"
 BLACKBURN_ROVERS = "365"
 EVERTON = "368"
 ARSENAL = "359"
+BRENTFORD = "Brentford"
+NOTTINGHAM_FOREST = "Nott'm Forest"
+BRIGHTON = "Brighton"
+CRYSTAL_PALACE = "Crystal Palace"
+BOURNEMOUTH = "Bournemouth"
+WOLVES = "Wolves"
+BURNLEY = "379"
+MANCHESTER_CITY = "382"
+SHEFFIELD_UNITED = "398"
+LUTON_TOWN = "301"
+NORWICH_CITY = "381"
+WATFORD = "395"
 EPL_TEAM_IDENTITY_MAP: dict[str, str] = {
     # ESPN
     "358": BOLTON_WANDERERS,
@@ -52,6 +64,42 @@ EPL_TEAM_IDENTITY_MAP: dict[str, str] = {
     "365": BLACKBURN_ROVERS,
     "368": EVERTON,
     "359": ARSENAL,
+    "380": WOLVES,
+    "393": NOTTINGHAM_FOREST,
+    "379": BURNLEY,
+    "382": MANCHESTER_CITY,
+    "349": BOURNEMOUTH,
+    "384": CRYSTAL_PALACE,
+    "331": BRIGHTON,
+    "337": BRENTFORD,
+    "398": SHEFFIELD_UNITED,
+    "301": LUTON_TOWN,
+    "381": NORWICH_CITY,
+    "395": WATFORD,
+    # FootballData
+    "Brentford": BRENTFORD,
+    "Arsenal": ARSENAL,
+    "Aston Villa": ASTON_VILLA,
+    "Southampton": SOUTHAMPTON,
+    "Everton": EVERTON,
+    "Nott'm Forest": NOTTINGHAM_FOREST,
+    "Leicester": LEICESTER_CITY,
+    "Brighton": BRIGHTON,
+    "Crystal Palace": CRYSTAL_PALACE,
+    "Man City": MANCHESTER_CITY,
+    "Liverpool": LIVERPOOL,
+    "Tottenham": TOTTENHAM_HOTSPUR,
+    "West Ham": WEST_HAM_UNITED,
+    "Chelsea": CHELSEA,
+    "Newcastle": NEWCASTLE_UNITED,
+    "Bournemouth": BOURNEMOUTH,
+    "Wolves": WOLVES,
+    "Ipswich": IPSWICH_TOWN,
+    "Fulham": FULHAM,
+    "Man United": MANCHESTER_UNITED,
+    "Sunderland": SUNDERLAND,
+    "Burnley": BURNLEY,
+    "Leeds": LEEDS_UNITED,
 }
 BOLEYN_GROUND = "304"
 STADIUM_OF_LIGHT = "194"
@@ -73,6 +121,21 @@ THE_VALLEY = "188"
 ST_JAMES_PARK = "308"
 TOUGHSHEET_COMMUNITY_STADIUM = "256"
 GOODISON_PARK = "253"
+TOTTENHAM_HOTSPUR_STADIUM = "7827"
+ETIHAD_STADIUM = "4036"
+SELHURT_PARK = "135"
+GTECH_COMMUNITY_STADIUM = "8480"
+EMIRATES_STADIUM = "2267"
+VITALITY_STADIUM = "6020"
+MOLINEUX_STADIUM = "136"
+LONDON_STADIUM = "6660"
+TURF_MOOR = "197"
+AMERICAN_EXPRESS_STADIUM = "4440"
+THE_CITY_GROUND = "131"
+KING_POWER_STADIUM = "5774"
+BRAMALL_LANE = "6291"
+KENILWORTH_ROAD = "3336"
+HILL_DICKINSON_STADIUM = "10318"
 EPL_VENUE_IDENTITY_MAP: dict[str, str] = {
     # ESPN
     "304": BOLEYN_GROUND,
@@ -95,6 +158,24 @@ EPL_VENUE_IDENTITY_MAP: dict[str, str] = {
     "308": ST_JAMES_PARK,
     "256": TOUGHSHEET_COMMUNITY_STADIUM,
     "253": GOODISON_PARK,
+    "135": SELHURT_PARK,
+    "136": MOLINEUX_STADIUM,
+    "197": TURF_MOOR,
+    "131": THE_CITY_GROUND,
+    # OddsPortal
+    "6660": LONDON_STADIUM,
+    "4440": AMERICAN_EXPRESS_STADIUM,
+    "8480": GTECH_COMMUNITY_STADIUM,
+    "2267": EMIRATES_STADIUM,
+    "6020": VITALITY_STADIUM,
+    "4684": ST_JAMES_PARK,
+    "7827": TOTTENHAM_HOTSPUR_STADIUM,
+    "4036": ETIHAD_STADIUM,
+    "4850": ST_MARYS_STADIUM,
+    "5774": KING_POWER_STADIUM,
+    "6291": BRAMALL_LANE,
+    "3336": KENILWORTH_ROAD,
+    "10318": HILL_DICKINSON_STADIUM,
 }
 EPL_PLAYER_IDENTITY_MAP: dict[str, str] = {}
 
