@@ -41,6 +41,9 @@ def _season_type_from_name(name: str) -> SeasonType:
         or "2003-2004 Barclays Premier League" in name
         or "2002-2003 Barclays Premier League" in name
         or "2001-2002 Barclays Premier League" in name
+        or "2025-26 LALIGA" in name
+        or "2025-26 German Bundesliga" in name
+        or "2024-25 German Bundesliga" in name
     ):
         return SeasonType.REGULAR
     if name == "Preseason" or "Spring Training" in name:
@@ -226,8 +229,10 @@ class ESPNLeagueModel(LeagueModel):
                     for game_model in self._produce_games(
                         week, week_count, season_type_json, pbar, cache_disabled
                     ):
-                        yield game_model
                         found_pages = True
+                        if game_model.dt.date() >= datetime.datetime.now().date():
+                            continue
+                        yield game_model
                     week_count += 1
                 if game_page >= weeks["pageCount"]:
                     break
