@@ -25,7 +25,7 @@ def create_tennisdata_team_model(
     set_three_points: int | None,
     set_four_points: int | None,
     set_five_points: int | None,
-    odds: str,
+    odds: str | None,
     session: ScrapeSession,
     dt: datetime.datetime,
     league: League,
@@ -37,7 +37,7 @@ def create_tennisdata_team_model(
         name=name,
         location=None,
         players=[create_tennisdata_player_model(name=name, league=league)],
-        odds=[create_tennisdata_odds_model(odds=odds)],
+        odds=[create_tennisdata_odds_model(odds=odds)] if odds is not None else [],
         points=points,
         ladder_rank=rank,
         news=create_google_news_models(name, session, dt, league),
